@@ -79,7 +79,12 @@ def score(
     smp_metrics = target_metrics(sample[outcome], target)
 
     # Return 0 if we our size is 0
-    if smp_metrics["size"] == 0 or pop_metrics["size"] == 0:
+    if (
+        smp_metrics["size"] == 0
+        or pop_metrics["size"] == 0
+        or smp_metrics["mean"] == pop_metrics["mean"]
+        or pop_metrics["std"] == 0
+    ):
         return 0
 
     return (
