@@ -24,12 +24,12 @@ def target_metrics(s: pd.Series, target: str = None) -> dict:
         if target == "min":
             values *= -1
 
-    mean = values.mean()
+    mean = values.mean() if values.size > 0 else 0
     above_mean = int((values >= mean).sum()) if mean > 0 else 0
 
     return {
         "mean": mean,
-        "std": values.std(ddof=0),
+        "std": values.std(ddof=0) if values.size > 0 else 0,
         "size": int(values.size),
         "size_above_mean": above_mean,
     }
