@@ -14,7 +14,7 @@ from mondobrain.error import (
 )
 from mondobrain.metrics import score
 from mondobrain.utils import constants, utilities
-from mondobrain.utils.data import is_discrete
+from mondobrain.utils.data import is_continuous, is_discrete
 
 
 def solve(
@@ -138,6 +138,9 @@ def _dimensionality_check(df: pd.DataFrame, outcome: str, target: str):
     col = df[outcome]
 
     if is_discrete(col):
+        if len(set(col)) == 1:
+            raise NotEnoughPointsError("Outcome column has only 1 modality")
+
         size = col[col == target].shape[0]
     else:
         if col.std() == 0:
@@ -167,19 +170,29 @@ def _exhaustive_single(df: pd.DataFrame, outcome: str, target: str, **kwargs) ->
 
 
 def _exhaustive_best(df: pd.DataFrame, outcome: str, **kwargs) -> List:
-    best_score = -99999.0
-    for target in df[outcome].unique():
+    best_score, best_rule, best_target = 0, None, None
+
+    targets = df[outcome].unique() if is_discrete(df[outcome]) else ["min", "max"]
+
+    for target in targets:
         try:
             rule = solve(df, outcome=outcome, target=target, **kwargs)
             if rule:
                 rule_score = score(df, outcome, target, rule)
             else:
                 rule_score = best_score
-            if rule_score > best_score:
+
+            if best_rule is None:
+                found_new_best = True
+            elif is_continuous(df[outcome]) and target == "min":
+                found_new_best = rule_score < best_score
+            else:
+                found_new_best = rule_score > best_score
+
+            if found_new_best:
                 best_rule = rule
                 best_target = target
-            else:
-                continue
+                best_score = rule_score
         except (NotEnoughPointsError, DataTransformationError):
             return []
 
@@ -198,7 +211,9 @@ def _exhaustive_best(df: pd.DataFrame, outcome: str, **kwargs) -> List:
 
 def _exhaustive_any(df: pd.DataFrame, outcome: str, **kwargs) -> List:
     rule_set = []
-    targets = df[outcome].unique()
+
+    targets = df[outcome].unique() if is_discrete(df[outcome]) else ["min", "max"]
+
     for target in targets:
         try:
             rule = solve(df, outcome=outcome, target=target, **kwargs)
